@@ -3,7 +3,7 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2002-2023, University of Amsterdam
+    Copyright (c)  2002-2024, University of Amsterdam
                               VU University Amsterdam
                               CWI, Amsterdam
                               SWI-Prolog Solutions b.v.
@@ -65,7 +65,14 @@
 :- autoload(library(ssl), [ssl_upgrade_legacy_options/2]).
 :- endif.
 :- use_module(library(socket)).
+:- use_module(library(settings)).
 
+:- setting(http:max_keep_alive_idle, number, 2,
+           "Time to keep idle keep alive connections around").
+:- setting(http:max_keep_alive_connections, integer, 10,
+           "Maximum number of client keep alive connections").
+:- setting(http:max_keep_alive_host_connections, integer, 2,
+           "Maximum number of client keep alive to a single host").
 
 /** <module> HTTP client library
 
@@ -1555,6 +1562,13 @@ http_scheme(https).
 %!  consider_keep_alive(+HeaderLines, +Parts, +Host,
 %!                      +Stream0, -Stream,
 %!                      +Options) is det.
+%
+%   If we have agree on a Keep-alive   connection, return a range stream
+%   rather than the original stream. We also  use the content length and
+%   a range stream if we are dealing   with an HTTPS connection. This is
+%   because not all servers seem to  complete the TLS closing handshake.
+%   If the server does not complete  this   we  receive  a TLS handshake
+%   error on end-of-file, causing the read to fail.
 
 consider_keep_alive(Lines, Parts, Host, StreamPair, In, Options) :-
     option(connection(Asked), Options),
@@ -1571,6 +1585,15 @@ consider_keep_alive(Lines, Parts, Host, StreamPair, In, Options) :-
                       [ size(Bytes),
                         onclose(keep_alive(StreamPair, HostPort))
                       ]).
+consider_keep_alive(Lines, Parts, _Host, StreamPair, In, _Options) :-
+    memberchk(scheme(https), Parts),
+    content_length(Lines, Bytes),
+    !,
+    stream_pair(StreamPair, In0, _),
+    stream_range_open(In0, In,
+                      [ size(Bytes),
+                        onclose(close_range(StreamPair))
+                      ]).
 consider_keep_alive(_, _, _, Stream, Stream, _).
 
 connection_address(Host, _, Host) :-
@@ -1583,27 +1606,50 @@ keep_alive(keep_alive) :- !.
 keep_alive(Connection) :-
     downcase_atom(Connection, 'keep-alive').
 
+%!  keep_alive(+StreamPair, +Host, +In, -Left) is det.
+%
+%   Callback when closing the range stream   used to process the content
+%   of the reply. This callback makes   the  stream available for future
+%   keep-alive connections or closes the stream. The stream is closed if
+%
+%     - There are too many bytes left unprocessed in the range stream.
+%     - There are too many pooled connections.
+
 :- public keep_alive/4.
+:- det(keep_alive/4).
 
 keep_alive(StreamPair, Host, _In, 0) :-
     !,
-    debug(http(connection), 'Adding connection to ~p to pool', [Host]),
-    add_to_pool(Host, StreamPair).
+    add_to_pool_or_close(Host, StreamPair).
 keep_alive(StreamPair, Host, In, Left) :-
-    Left < 100,
-    debug(http(connection), 'Reading ~D left bytes', [Left]),
-    read_incomplete(In, Left),
+    (   Left < 100,
+        debug(http(connection), 'Reading ~D left bytes', [Left]),
+        read_incomplete(In, Left)
+    ->  add_to_pool_or_close(Host, StreamPair)
+    ;   debug(http(connection),
+              'Closing connection due to excessive unprocessed input', []),
+        close_keep_alive(StreamPair)
+    ).
+
+add_to_pool_or_close(Host, StreamPair) :-
     add_to_pool(Host, StreamPair),
-    !.
-keep_alive(StreamPair, _, _, _) :-
-    debug(http(connection),
-          'Closing connection due to excessive unprocessed input', []),
+    !,
+    debug(http(connection), 'Added connection to ~p to pool', [Host]).
+add_to_pool_or_close(Host, StreamPair) :-
+    close_keep_alive(StreamPair),
+    debug(http(connection), 'Closed connection to ~p [pool full]', [Host]).
+
+close_keep_alive(StreamPair) :-
     (   debugging(http(connection))
     ->  catch(close(StreamPair), E,
               print_message(warning, E))
     ;   close(StreamPair, [force(true)])
     ).
 
+:- public close_range/3.
+close_range(StreamPair, _Raw, _BytesLeft) :-
+    close(StreamPair, [force(true)]).
+
 %!  read_incomplete(+In, +Left) is semidet.
 %
 %   If we have not all input from  a Keep-alive connection, read the
@@ -1621,30 +1667,55 @@ read_incomplete(In, Left) :-
     connection_pool/4,              % Hash, Address, Stream, Time
     connection_gc_time/1.
 
+%!  add_to_pool(+Address, +StreamPair) is semidet.
+%
+%   Add a connection  to  the  keep-alive   pool  after  completing  the
+%   interaction. Fails if there are already  too many connections in the
+%   pool.
+
 add_to_pool(Address, StreamPair) :-
     keep_connection(Address),
     get_time(Now),
     term_hash(Address, Hash),
     assertz(connection_pool(Hash, Address, StreamPair, Now)).
 
+%!  get_from_pool(+Address, -StreamPair) is nondet.
+%
+%   Get an existing Keep-Alive connection to  Address as StreamPair. The
+%   caller relies on non-determinism of this   predicate  to try another
+%   connection if the returned one is  already   closed  by the peer. We
+%   cannot rely on the non-determinism of retract/1 as that respects the
+%   _logical update view_. Therefore, we must   use retract/1 and commit
+%   as retract/1 guarantees that  the  first   retracted  clause  is not
+%   already retracted.
+
 get_from_pool(Address, StreamPair) :-
     term_hash(Address, Hash),
-    retract(connection_pool(Hash, Address, StreamPair, _)).
+    repeat,
+    (   retract(connection_pool(Hash, Address, StreamPair, _))
+    ->  true
+    ;   !,
+        fail
+    ).
 
 %!  keep_connection(+Address) is semidet.
 %
-%   Succeeds if we want to keep   the  connection open. We currently
-%   keep a maximum of 10 connections  waiting   and  a  maximum of 2
-%   waiting for the same address. Connections   older than 2 seconds
-%   are closed.
+%   Succeeds if we want to keep the connection open. We currently keep a
+%   maximum of `http:max_keep_alive_connections` connections waiting and
+%   a maximum of `http:max_keep_alive_host_connections`  waiting for the
+%   same  address.  Connections  older  than  `http:max_keep_alive_idle`
+%   seconds are closed.
 
 keep_connection(Address) :-
-    close_old_connections(2),
+    setting(http:max_keep_alive_idle, Time),
+    close_old_connections(Time),
     predicate_property(connection_pool(_,_,_,_), number_of_clauses(C)),
-    C =< 10,
+    setting(http:max_keep_alive_connections, MaxConnections),
+    C =< MaxConnections,
     term_hash(Address, Hash),
     aggregate_all(count, connection_pool(Hash, Address, _, _), Count),
-    Count =< 2.
+    setting(http:max_keep_alive_host_connections, MaxHostConnections),
+    Count =< MaxHostConnections.
 
 close_old_connections(Timeout) :-
     get_time(Now),
@@ -1694,6 +1765,10 @@ keep_alive_error(error(io_error(_,_), _), StreamPair) :-
     close(StreamPair, [force(true)]),
     debug(http(connection), 'IO error on Keep-alive connection', []),
     fail.
+keep_alive_error(error(existence_error(http_reply, _URL), _), _) :-
+    !,
+    debug(http(connection), 'Got empty reply on Keep-alive connection', []),
+    fail.
 keep_alive_error(Error, StreamPair) :-
     close(StreamPair, [force(true)]),
     throw(Error).
