@@ -112,8 +112,8 @@ void		freeHeap(void *mem, size_t n);
 #endif /*DMALLOC*/
 int		enableSpareStack(Stack s, int always);
 void		enableSpareStacks(void);
-int		outOfStack(void *stack, stack_overflow_action how);
-int		raiseStackOverflow(int which);
+bool		outOfStack(void *stack, stack_overflow_action how);
+bool		raiseStackOverflow(int which);
 void		outOfCore(void) NORETURN;
 Word		allocGlobal(size_t words);
 Word		allocGlobalNoShift(size_t words);
