@@ -154,9 +154,9 @@ activateProfiler(DECL_LD prof_status active)
 
   updateAlerted(LD);
 
-  LD->profile.sum_ok = FALSE;
+  LD->profile.sum_ok = false;
 
-  return TRUE;
+  return true;
 }
 
 
@@ -177,6 +177,8 @@ thread_prof_ticks(DECL_LD)
 
 #ifdef __WINDOWS__
 
+#include <math.h>
+
 static UINT         timer;			/* our MM timer */
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -208,7 +210,7 @@ startProfiler(prof_status how)
   (void)how;
 
   rval = timeSetEvent(10,
-		      5,		/* resolution (milliseconds) */
+		      round(LD->profile.sample_period/1000),		/* resolution (milliseconds) */
 		      callTimer,
 		      (DWORD_PTR)0,
 		      TIME_PERIODIC);
@@ -288,9 +290,9 @@ startProfiler(prof_status how)
   timer_signal = sig;
 
   value.it_interval.tv_sec  = 0;
-  value.it_interval.tv_usec = 5000;		/* 5ms for real; also ok for cpu */
+  value.it_interval.tv_usec = LD->profile.sample_period;  // period in usecs.
   value.it_value.tv_sec  = 0;			/* on systems where 0 means now */
-  value.it_value.tv_usec = 5000;
+  value.it_value.tv_usec = LD->profile.sample_period;
 
   if ( setitimer(timer, &value, &ovalue) != 0 )
     return PL_error(NULL, 0, MSG_ERRNO, ERR_SYSCALL, setitimer);
@@ -335,7 +337,7 @@ stopProfiler(void)
 #endif
   }
 
-  return TRUE;
+  return true;
 }
 
 
@@ -353,21 +355,21 @@ get_prof_status(term_t t, prof_status *s)
   { switch(a)
     { case ATOM_false:
 	*s = PROF_INACTIVE;
-        return TRUE;
+        return true;
       case ATOM_true:
       case ATOM_cputime:
 	*s = PROF_CPU;
-        return TRUE;
+        return true;
       case ATOM_walltime:
 	*s = PROF_WALL;
-        return TRUE;
+        return true;
       default:
 	PL_domain_error("profile_status", t);
-        return FALSE;
+        return false;
     }
   }
 
-  return FALSE;
+  return false;
 }
 
 
@@ -380,11 +382,11 @@ PRED_IMPL("profiler", 2, profiler, 0)
 		      LD->profile.active == PROF_INACTIVE ? ATOM_false :
 		      LD->profile.active == PROF_CPU ? ATOM_cputime :
 		      ATOM_walltime) )
-    return FALSE;
+    return false;
   if ( PL_compare(A1, A2) == 0 )
-    return TRUE;
+    return true;
   if ( !get_prof_status(A2, &val) )
-    return FALSE;
+    return false;
   if ( val == LD->profile.active )
     succeed;
 
@@ -507,7 +509,7 @@ PRED_IMPL("$prof_node", 8, prof_node, 0)
   call_node *n = NULL;
 
   if ( !get_node(A1, &n) )
-    return FALSE;
+    return false;
 
   collectSiblingsTime();
 
@@ -758,9 +760,9 @@ get_handle(term_t t, void **handle)
   for(i=0; i<MAX_PROF_TYPES; i++)
   { if ( types[i] && types[i]->get )
     { switch( (*types[i]->get)(t, handle) )
-      { case TRUE:
+      { case true:
 	  succeed;
-	case FALSE:
+	case false:
 	  break;
 	default:
 	  assert(0);
@@ -819,30 +821,37 @@ PRED_IMPL("$prof_procedure_data", 8, prof_procedure_data, PL_FA_TRANSPARENT)
   free_relatives(sum.callers);
   free_relatives(sum.callees);
 
-  return rc ? TRUE : FALSE;
+  return rc ? true : false;
 }
 
 
-/** '$prof_statistics'(-Samples, -Ticks, -AccountingTicks, -Time, -Nodes)
+/** '$prof_statistics'(-Samples, -Ticks, -AccountingTicks,
+		       -Time, -Nodes, -Period, -Ports)
 
 @arg Samples is the number of times the statistical profiler was called.
 @arg Ticks   is the number of virtual ticks during profiling
 @arg AccountingTicks are tick spent on accounting
 @arg Time    is the total CPU time spent profiling
 @arg Nodes   is the number of nodes in the call tree
+@arg Period  is the number of microseconds between samples
+@arg Ports   is one of `true`, `false` or `classic`
 */
 
 static
-PRED_IMPL("$prof_statistics", 5, prof_statistics, 0)
+PRED_IMPL("$prof_statistics", 7, prof_statistics, 0)
 { PRED_LD
-  if ( PL_unify_uint64(A1, LD->profile.samples) &&
-       PL_unify_uint64(A2, LD->profile.ticks) &&
-       PL_unify_uint64(A3, LD->profile.accounting_ticks) &&
-       PL_unify_float( A4, LD->profile.time) &&
-       PL_unify_uint64(A5, LD->profile.nodes) )
-    succeed;
 
-  fail;
+  return
+    ( PL_unify_uint64(A1, LD->profile.samples) &&
+      PL_unify_uint64(A2, LD->profile.ticks) &&
+      PL_unify_uint64(A3, LD->profile.accounting_ticks) &&
+      PL_unify_float( A4, LD->profile.time) &&
+      PL_unify_uint64(A5, LD->profile.nodes) &&
+      PL_unify_integer(A6, LD->profile.sample_period) &&
+      PL_unify_atom(A7, LD->profile.ports_control == PROFC_FALSE ? ATOM_false :
+			LD->profile.ports_control == PROFC_TRUE  ? ATOM_true :
+								   ATOM_classic)
+    );
 }
 
 
@@ -862,7 +871,7 @@ prof_clear_environments(DECL_LD LocalFrame fr)
     return NULL;
 
   for(;;)
-  { if ( true(fr, FR_MARKED) )
+  { if ( ison(fr, FR_MARKED) )
       return NULL;
     set(fr, FR_MARKED);
     LD->gc._local_frames++;
@@ -924,7 +933,7 @@ resetProfiler(DECL_LD)
   LD->profile.ticks            = 0;
   LD->profile.accounting_ticks = 0;
   LD->profile.time             = 0.0;
-  LD->profile.accounting       = FALSE;
+  LD->profile.accounting       = false;
 
   succeed;
 }
@@ -943,12 +952,27 @@ PRED_IMPL("reset_profiler", 0, reset_profiler, 0)
 		 *******************************/
 
 static
-PRED_IMPL("$profile", 2, profile, PL_FA_TRANSPARENT)
+PRED_IMPL("$profile", 4, profile, PL_FA_TRANSPARENT)
 { int rc;
   prof_status val;
 
   if ( !get_prof_status(A2, &val) )
-    return FALSE;
+    return false;
+
+  atom_t ports_opt;
+  PL_get_atom_ex(A3, &ports_opt);
+  switch (ports_opt)
+  { case ATOM_false: LD->profile.ports_control = PROFC_FALSE;   break;
+    case ATOM_true:  LD->profile.ports_control = PROFC_TRUE;    break;
+    default:         LD->profile.ports_control = PROFC_CLASSIC;
+  }
+
+  LD->profile.sample_period = 5000;  // default period in usecs.
+  double rate;
+  if ( PL_get_float_ex(A4, &rate) )
+    LD->profile.sample_period = (unsigned int)(1000000/rate);
+  else
+    return false;
 
   resetProfiler();
   startProfiler(val);
@@ -1032,7 +1056,7 @@ static call_node *
 prof_call(DECL_LD void *handle, PL_prof_type_t *type)
 { call_node *node = LD->profile.current;
 
-  LD->profile.accounting = TRUE;
+  LD->profile.accounting = true;
 
   if ( !node )				/* root-node of the profile */
   { for(node = LD->profile.roots; node; node=node->next)
@@ -1042,7 +1066,7 @@ prof_call(DECL_LD void *handle, PL_prof_type_t *type)
 	DEBUG(MSG_PROF_CALLTREE,
 	      Sdprintf("Call: existing root %s\n", node_name(node)));
 
-	LD->profile.accounting = FALSE;
+	LD->profile.accounting = false;
 	return node;
       }
     }
@@ -1058,7 +1082,7 @@ prof_call(DECL_LD void *handle, PL_prof_type_t *type)
     node->next = LD->profile.roots;
     LD->profile.roots = node;
     LD->profile.current = node;
-    LD->profile.accounting = FALSE;
+    LD->profile.accounting = false;
     DEBUG(MSG_PROF_CALLTREE,
 	  Sdprintf("Call: new root %s\n", node_name(node)));
 
@@ -1070,9 +1094,9 @@ prof_call(DECL_LD void *handle, PL_prof_type_t *type)
   { node->recur++;
     DEBUG(MSG_PROF_CALLTREE,
 	  Sdprintf("Call: direct recursion on %s\n", node_name(node)));
-    LD->profile.accounting = FALSE;
+    LD->profile.accounting = false;
     return node;
-  } else				/* from some parent */
+  } else if ( LD->profile.ports_control != PROFC_TRUE )
   { void *parent = node->handle;
 
     for(node=node->parent; node; node = node->parent)
@@ -1084,7 +1108,7 @@ prof_call(DECL_LD void *handle, PL_prof_type_t *type)
 	LD->profile.current = node;
 	DEBUG(MSG_PROF_CALLTREE,
 	      Sdprintf("Call: indirect recursion on %s\n", node_name(node)));
-	LD->profile.accounting = FALSE;
+	LD->profile.accounting = false;
 	return node;
       }
     }
@@ -1096,7 +1120,7 @@ prof_call(DECL_LD void *handle, PL_prof_type_t *type)
       node->calls++;
       DEBUG(MSG_PROF_CALLTREE,
 	    Sdprintf("Call: existing child %s\n", node_name(node)));
-      LD->profile.accounting = FALSE;
+      LD->profile.accounting = false;
       return node;
     }
   }
@@ -1114,7 +1138,7 @@ prof_call(DECL_LD void *handle, PL_prof_type_t *type)
   LD->profile.current = node;
   DEBUG(MSG_PROF_CALLTREE,
 	Sdprintf("Call: new child %s\n", node_name(node)));
-  LD->profile.accounting = FALSE;
+  LD->profile.accounting = false;
 
   return node;
 }
@@ -1122,7 +1146,7 @@ prof_call(DECL_LD void *handle, PL_prof_type_t *type)
 
 call_node *
 profCall(DECL_LD Definition def)
-{ if ( true(def, P_NOPROFILE) )
+{ if ( ison(def, P_NOPROFILE) )
     return LD->profile.current;
 
   acquireModulePtr(def->module);
@@ -1148,15 +1172,19 @@ profResumeParent(DECL_LD struct call_node *node)
   if ( node && node->magic != PROFNODE_MAGIC )
     return;
 
-  LD->profile.accounting = TRUE;
-  for(n=LD->profile.current; n && n != node; n=n->parent)
-  { DEBUG(MSG_PROF_CALLTREE,
-	  Sdprintf("Exit: %s\n", node_name(n)));
-    n->exits++;
-  }
-  LD->profile.accounting = FALSE;
+  LD->profile.accounting = true;
 
+  if ( LD->profile.ports_control  != PROFC_FALSE )
+  { for(n=LD->profile.current; n && n != node; n=n->parent)
+    { DEBUG(MSG_PROF_CALLTREE,
+	    Sdprintf("Exit: %s\n", node_name(n)));
+      n->exits++;
+    }
+  }
   LD->profile.current = node;
+
+  LD->profile.accounting = false;
+
 }
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1194,12 +1222,12 @@ lookback(call_node *from_node, call_node *to_node)
 
   while( node )
   { if ( node == to_node )
-      return TRUE;
+      return true;
     else
       node = node->parent;
   }
 
-  return FALSE;
+  return false;
 }
 
 static void
@@ -1217,12 +1245,13 @@ profFailToCP(struct call_node *current, struct call_node *cp_node)
 
 void
 profFail(DECL_LD struct call_node *cp_node)
-{ LD->profile.accounting = TRUE;
+{ LD->profile.accounting = true;
 
-  profFailToCP(LD->profile.current, cp_node);
+  if ( LD->profile.ports_control != PROFC_FALSE )
+    profFailToCP(LD->profile.current, cp_node);
   LD->profile.current = cp_node;
 
-  LD->profile.accounting = FALSE;
+  LD->profile.accounting = false;
 }
 
 void
@@ -1241,18 +1270,18 @@ PL_register_profile_type(PL_prof_type_t *type)
 
   for(i=0; i<MAX_PROF_TYPES; i++)
   { if ( types[i] == type )
-      return TRUE;
+      return true;
   }
   for(i=0; i<MAX_PROF_TYPES; i++)
   { if ( !types[i] )
     { types[i] = type;
       type->magic = PROFTYPE_MAGIC;
-      return TRUE;
+      return true;
     }
   }
 
   assert(0);
-  return FALSE;
+  return false;
 }
 
 
@@ -1299,7 +1328,7 @@ collectSiblingsTime(DECL_LD)
     for(n=LD->profile.roots; n; n=n->next)
       collectSiblingsNode(n);
 
-    LD->profile.sum_ok = TRUE;
+    LD->profile.sum_ok = true;
   }
 }
 
@@ -1347,7 +1376,7 @@ freeProfileData(void)
 
 int
 PL_register_profile_type(PL_prof_type_t *type)
-{ return FALSE;
+{ return false;
 }
 
 void *
@@ -1369,12 +1398,12 @@ PL_prof_exit(void *node)
 
 BeginPredDefs(profile)
 #if O_PROFILE
-  PRED_DEF("$profile", 2, profile, PL_FA_TRANSPARENT)
+  PRED_DEF("$profile", 4, profile, PL_FA_TRANSPARENT)
   PRED_DEF("profiler", 2, profiler, 0)
   PRED_DEF("reset_profiler", 0, reset_profiler, 0)
   PRED_DEF("$prof_node", 8, prof_node, 0)
   PRED_DEF("$prof_sibling_of", 2, prof_sibling_of, PL_FA_NONDETERMINISTIC)
   PRED_DEF("$prof_procedure_data", 8, prof_procedure_data, PL_FA_TRANSPARENT)
-  PRED_DEF("$prof_statistics", 5, prof_statistics, 0)
+  PRED_DEF("$prof_statistics", 7, prof_statistics, 0)
 #endif
 EndPredDefs
