@@ -46,6 +46,9 @@
 :- use_module(library(lists)).
 :- use_module(library(option)).
 :- use_module(library(error)).
+:- if(current_prolog_flag(threads, true)).
+:- use_module(library(thread)).
+:- endif.
 
 :- set_test_options([ load(always)
                     ]).
@@ -83,701 +86,11 @@ prolog:message(test(no_pkg(Pkg))) -->
 
 :- setenv('TZ', 'CET').
 
-                 /*******************************
-                 *            SYNTAX            *
-                 *******************************/
-
-syntax(op-1) :-
-    atom_to_term("3+4*5", +(3,*(4,5)), []).
-syntax(op-2) :-
-    atom_to_term("1+2+3", +(+(1,2),3), []).
-syntax(op-3) :-
-    catch(atom_to_term("a:-b:-c", _, _), E, true),
-    E = error(syntax_error(operator_clash), _).
-syntax(op-4) :-
-    op(600, fx, op1),
-    atom_to_term("op1 1+2", op1(+(1,2)), []).
-syntax(op-5) :-
-    op(600, fx, op1),
-    catch(atom_to_term("op1 op1 1", _, _), E, true),
-    E = error(syntax_error(operator_clash), _).
-syntax(op-6) :-
-    op(600, fy, op1),
-    atom_to_term("op1 op1 1", op1(op1(1)), []).
-syntax(op-7) :-
-    op(600, fy, op1),
-    op(500, xf, op2),
-    catch(atom_to_term("op1 a op2", op1(op2(a)), []), E, true),
-    E = error(syntax_error(operator_clash), _).
-syntax(op-8) :-                         % assume 200 fy and 500 yfx
-    atom_to_term("- - a", -(-(a)), []).
-syntax(atom-1) :-
-    atom_codes('\003\\'\n\x80\', X),
-    X == [3, 39, 10, 128].
-syntax(char-1) :-
-    10 == 0'\n.
-syntax(char-2) :-
-    52 == 0'\x34.
-syntax(char-3) :-
-    "\\" =:= 0'\\.
-syntax(char-4) :-
-    1-48 == 1-0'0.
-syntax(cannot_start_term-1) :-
-    catch(term_to_atom(_T, 'p(]'), E, true),
-    E = error(syntax_error(cannot_start_term), _).
-
-
-:- op(100, yf, af).
-
-syntax(string-1) :-
-    '\c ' == ''.
-syntax(string-2) :-
-    'x\c y' == xy.
-syntax(quote-1) :-
-    catch(atom_to_term('\'\\x\'', _, _), E, true),
-    E = error(syntax_error(undefined_char_escape(x)), _).
-syntax(quote-2) :-
-    '\x61' == a.
-syntax(quote-3) :-
-    '\x61\' == a.
-syntax(quote-4) :-
-    char_code('\'', 39).
-syntax(quote-5) :-
-    0'\' == 0''.
-syntax(quote-6) :-
-    0'\' == 0'''.
-syntax(quote-7) :-
-    atom_to_term('\'\\\n\'', T, _),
-    T == ''.
-syntax(base-1) :-
-    1+1 == 1+1.
-syntax(base-2) :-
-    16'af == 175.
-syntax(base-3) :-
-    10 af == af(10).
-syntax(base-4) :-
-    A = 1, B is A+1, B == 2.
-syntax(base-5) :-
-    A is 1.0e+0+1, A == 2.0.
-syntax(number-2) :-
-    catch(atom_to_term('2\'', _, _), E, true),
-    E = error(syntax_error(end_of_file), _).
-syntax(zero-1) :-
-    term_to_atom(T, 'hello("\000\x")'),
-    T = hello(A0),
-    (   A0 == [0,120]               % depending on the double quotes flag
-    ;   string_codes(A0, [0,120])
-    ;   A0 == ['\u0000', x]
-    ),
-    !.
-syntax(latin-1) :-
-    atom_codes(A, [247]),
-    atom_to_term(A, T, []),
-    atom_codes(T, [247]).
-
-:- op(0, yf, af).
-
-
-                 /*******************************
-                 *             WRITE            *
-                 *******************************/
-
-:- op(200, fx, op_fa).
-
-write_test(q-1) :-
-    T = -(0),
-    term_to_atom(T, X),
-    term_to_atom(T2, X),
-    T == T2.
-write_test(q-2) :-
-    T = +(0),
-    term_to_atom(T, X),
-    term_to_atom(T2, X),
-    T == T2.
-write_test(q-3) :-
-    term_to_atom(+(a), X), X == '+a'.
-write_test(q-4) :-
-    term_to_atom('/*', X), X == '\'/*\''.   %0'
-write_test(q-5) :-
-    term_to_atom('/**', X), X == '\'/**\''.
-write_test(q-6) :-
-    term_to_atom('*/*', X), X == '*/*'.
-write_test(q-7) :-
-    term_to_atom(p((0|a)), X), X == 'p((0|a))'.
-write_test(q-8) :-
-    term_to_atom(p((a|b)), X), X == 'p((a|b))'.
-write_test(q-9) :-
-    term_to_atom(., X), X == '\'.\''.
-write_test(op-1) :-
-    term_to_atom(-((a,b)), X), X == '- (a,b)'.
-write_test(op-2) :-
-    term_to_atom(op_fa((a,b)), X), X == 'op_fa (a,b)'.
-write_test(op-3) :-
-    term_to_atom(dynamic((a,b)), X), X == 'dynamic a,b'.
-write_test(c-1) :-
-    T = [a,b,c|T],
-    term_to_atom(T, X),
-    term_to_atom(@(T2,S2), X),
-    maplist(call, S2),
-    T2 =@= T.
-write_test(s-1) :-
-    term_to_atom([(a,b)], X),
-    X = '[(a,b)]'.
-
-
-                 /*******************************
-                 *            FORMAT            *
-                 *******************************/
-
-format_test(intD-1) :-
-    format(atom(X), '~D', [1000]),
-    X == '1,000'.
-format_test(intD-2) :-
-    format(atom(X), '~2D', [1000]),
-    X == '10.00'.
-format_test(intD-3) :-
-    format(atom(X), '~2D', [100000]),
-    X == '1,000.00'.
-format_test(intr-1) :-
-    format(atom(X), '~16r', [1000]),
-    X == '3e8'.
-format_test(intR-1) :-
-    format(atom(X), '~16R', [1000]),
-    X == '3E8'.
-format_test(large_float-1) :-
-    format(atom(X), '~6f', [1e100]),
-    atom_length(X, Len),
-    Len == 108.                     % 1 with 100 0s + ".000000" = 108.
-format_test(oncodes-1) :-
-    format(codes(C), 'hello ~w', [world]),
-    atom_codes('hello world', C).
-format_test(oncodes-2) :-
-    format(codes(C,T), 'hello ~w', [world]),
-    atom_codes('hello world', HW),
-    append(HW, T2, C2),
-    C-T =@= C2-T2.
-format_test(onstring-1) :-
-    format(string(S), 'hello ~w', [world]),
-    string(S),
-    atom_string('hello world', S).
-
-
-                 /*******************************
-                 *             UNIFY            *
-                 *******************************/
-
-%       Some cyclic unification tests (normal unification should be fixed
-%       already).
-
-unify(cycle-1) :-                       % Kuniaki Mukai
-    X = f(Y), Y=f(X), X=Y.
-unify(cycle-2) :-                       % Kuniaki Mukai
-    X = f(X), Y=f(Y), X=f(Y).
-
-
-                 /*******************************
-                 *    UNIFY-WITH-OCCURS-CHECK   *
-                 *******************************/
-
-occurs_check(simple-1) :-
-    \+ unify_with_occurs_check(A, list(A)).
-occurs_check(simple-2) :-
-    unify_with_occurs_check(_A, _B).
-occurs_check(attvar-1) :-               % test wakeup
-    freeze(X, X = Y),
-    unify_with_occurs_check(X, a),
-    Y == a.
-occurs_check(attvar-2) :-               % test occurs-check
-    freeze(A, true),
-    \+ unify_with_occurs_check(A, list(A)).
-occurs_check(attvar-3) :-
-    freeze(A, true),
-    unify_with_occurs_check(A, A).
-occurs_check(attvar-4) :-
-    freeze(A, true),
-    freeze(B, true),
-    unify_with_occurs_check(A, B).
-
-
-                 /*******************************
-                 *             CYCLIC           *
-                 *******************************/
-
-cyclic(term_hash-1) :-
-    X = f(X), term_hash(X, T),
-    integer(T).
-cyclic(streq-1) :-
-    X = [X], Y = [Y], X =@= Y.
-cyclic(test-1) :-
-    X = f(X),
-    cyclic_term(X).
-cyclic(test-2) :-
-    X = f(X),
-    cyclic_term(a(X, a)).
-cyclic(test-3) :-
-    X = f(X),
-    cyclic_term(a(a, X)).
-cyclic(test-4) :-
-    acyclic_term(f(x)).
-cyclic(test-5) :-
-    acyclic_term(_).
-cyclic(test-6) :-
-    X = f(a), acyclic_term(a(X, X)).
-cyclic(list-1) :-
-    L = [a|L], \+ is_list(L).
-cyclic(sort-1) :-
-    L = [a,b,c|L],
-    sort(L, List),
-    List == [a,b,c].
-
-
-                 /*******************************
-                 *          UNIFIABLE           *
-                 *******************************/
-
-unifiable(unifiable-1) :-
-    unifiable(X, 1, S),
-    S == [X=1].
-unifiable(unifiable-2) :-
-    unifiable(a(X,X), a(Y,Z), S),
-    S == [Z=X, Y=X].
-unifiable(gc-1) :-
-    trim_stacks,
-    (   between(2, 10, N),
-        Len is 1<<N,
-        numlist(1, Len, L1),
-        attvar_list(Len, L2),
-        unifiable(L1, L2, _Unifier),
-        fail
-    ;   true
-    ).
-
-attvar_list(0, []) :- !.
-attvar_list(N, [H|T]) :-
-    freeze(H, integer(H)),
-    N2 is N - 1,
-    attvar_list(N2, T).
-
-
-                 /*******************************
-                 *      INTEGER ARITHMETIC      *
-                 *******************************/
-
-arithmetic(between-1) :-
-    between(0, 10, 5).
-arithmetic(between-2) :-
-    \+ between(0, 10, 20).
-arithmetic(between-3) :-
-    findall(X, between(1, 6, X), Xs),
-    Xs == [1, 2, 3, 4, 5, 6].
-arithmetic(between-4) :-
-    findall(X, between(-4, -1, X), Xs),
-    Xs == [-4, -3, -2, -1].
-arithmetic(succ-1) :-
-    succ(0, X), X == 1.
-arithmetic(succ-2) :-
-    \+ succ(_, 0).
-arithmetic(succ-3) :-
-    catch(succ(_, -1), E, true),
-    E = error(domain_error(not_less_than_zero, -1), _).
-arithmetic(plus-1) :-
-    plus(1, 2, 3).
-
-                 /*******************************
-                 *        SIMPLE THINGS         *
-                 *******************************/
-
-arithmetic(arith-1) :-
-    A is 5 + 5,
-    A == 10.
-arithmetic(arith-2) :-
-    0 =:= -5 + 2.5 * 2.
-arithmetic(arith-3) :-
-    A is pi,
-    B is cos(A),
-    B =:= -1.
-arithmetic(arith-4) :-
-    0 =:= 10 - 3.4 - 6.6.
-arithmetic(arith-5) :-
-    1 =:= integer(0.5).
-arithmetic(arith-6) :-
-    4.5 =:= abs(-4.5),
-    4 =:= abs(4),
-    4 =:= abs(-4).
-arithmetic(arith-7) :-
-    5.5 =:= max(1, 5.5).
-arithmetic(arith-8) :-
-    -6 is min(-6, -5.5).
-arithmetic(arith-9) :-
-    4000 =:= integer(10000 * float_fractional_part(1.0e10 + 0.4)).
-arithmetic(arith-10) :-
-    -4000 =:= integer(10000 * float_fractional_part(-1.0e10 - 0.4)).
-arithmetic(float_fractional_part-1) :-
-    0 is float_fractional_part(4).
-arithmetic(arith-11) :-
-    1.0 is sin(pi/2),
-    \+ 1 is sin(pi/2).
-arithmetic(arith-12) :-
-    1.0 is float(sin(pi/2)).
-arithmetic(arith-13) :-
-    1.0 =:= sin(pi/2).
-arithmetic(sign-1) :-
-    -1   is sign(-1),   0   is sign(0),   1   is sign(1).
-arithmetic(sign-2) :-
-    -1.0 is sign(-1.5), 0.0 is sign(0.0), 1.0 is sign(pi).
-arithmetic(sign-3) :-
-    0.0 is sign(-0.0).
-arithmetic(copysign-1) :-
-    -1 is copysign(1, -0.0),
-     1 is copysign(1, 0.0).
-arithmetic(copysign-2) :-
-    -2.0 is copysign(2.0, -0.0),
-    2.0 is copysign(2.0, 0.0).
-arithmetic(copysign-3) :-
-    1  is copysign(1, 1),
-    -1 is copysign(1, -1).
-arithmetic(abs-1) :-
-    A is abs(-0.0),
-    A == 0.0.
-arithmetic(floor-1) :-
-    0 is floor(0.0),
-    0 is floor(0.9),
-    -1 is floor(-0.1),
-    -1 is floor(-0.9).
-arithmetic(ceil-1) :-
-    0 is ceil(0.0),
-    1 is ceil(0.9),
-    0 is ceil(-0.1),
-    0 is ceil(-0.9).
-arithmetic(truncate-1) :-
-    1 is truncate(1.1),
-    1 is truncate(1.9),
-    -1 is truncate(-1.1),
-    -1 is truncate(-1.9).
-:- if(current_prolog_flag(bounded, false)).
-arithmetic(floor-2) :-
-    A is floor(9223372036854775808.000000),
-    A == 9223372036854775808.
-arithmetic(ceil-2) :-
-    A is ceil(9223372036854775808.000000),
-    A == 9223372036854775808.
-:- endif.
-arithmetic(round-2) :-
-    A is round(9223372036854775807.000000),
-    A == 9223372036854775807.
-arithmetic(integer-2) :-
-    A is integer(9223372036854775807.000000),
-    A == 9223372036854775807.
-
-
-                 /*******************************
-                 *          BIG NUMBERS         *
-                 *******************************/
-
-arithmetic(int-1) :-
-    A is 1<<31, integer(A).
-arithmetic(cmp-1) :-
-    A is 100.0e6, 67 < A.
-
-
-                 /*******************************
-                 *            FLOATS            *
-                 *******************************/
-
-foverflow(X) :-
-    X2 is X * pi * pi,
-    foverflow(X2),
-    1 = 1.                  % avoid tail-recursion to force termination
-
-ftest(4.5).
-ftest :-
-    ftest(4.5).
-
-floattest(float-1) :-
-    ftest(X),
-    X == 4.5.
-floattest(float-2) :-
-    ftest.
-floattest(float-3) :-
-    erase_all(f),                   % play safe
-    recorda(f, 6.7, Ref),
-    recorded(f, X),
-    X == 6.7,
-    erase(Ref).
-floattest(float-4) :-
-    X is 10.67,
-    X == 10.67.
-floattest(float-5) :-
-    clause(ftest(X), true),
-    X == 4.5.
-floattest(float-6) :-
-    clause(ftest, ftest(X)),
-    X == 4.5.
-floattest(float-7) :-
-    catch(foverflow(2.2), E, true),
-    E = error(evaluation_error(float_overflow), _).
-floattest(float-8) :-
-    catch(foverflow(-2.2), E, true),
-    E = error(evaluation_error(float_overflow), _).
-
 
                  /*******************************
                  *     UNBOUNDED ARITHMETIC     *
                  *******************************/
 
-:- dynamic
-    gmp_clause/2.
-
-fac(1,1) :- !.
-fac(X,N) :-
-    X > 1,
-    X2 is X - 1,
-    fac(X2, N0),
-    N is N0 * X.
-
-oefac(X, Fac) :-                        % produce large pos and neg ints
-    fac(X, F0),
-    odd_even_neg(X, F0, Fac).
-
-odd_even_neg(X, V0, V) :-
-    (   X mod 2 =:= 0
-    ->  V = V0
-    ;   V is -V0
-    ).
-
-:- if(current_prolog_flag(bounded, false)). % GMP implies rational
-
-ratp(C, X, X ) :-
-    C =< 0,
-    !.
-ratp(Count, In, Out) :-
-    succ(Count0, Count),
-    T is In + (In rdiv 2),
-    ratp(Count0, T, Out).
-
-dec(X, Y) :-
-    Y is X - 1.
-
-gmp(add-promote1) :-
-    A is 1 + 9223372036854775807,
-    A =:= 9223372036854775808.
-gmp(add-promote2) :-
-    A is -9223372036854775808 + -1,
-    A =:= -9223372036854775809.
-gmp(neg-1) :-                           % check conversion of PLMININT
-    A is -9223372036854775808,
-    -A =:= 9223372036854775808.
-gmp(neg-2) :-
-    A is -(1<<63+1), A == -9223372036854775809.
-gmp(neg-promote) :-
-    A is 0 - -9223372036854775808,
-    A =:= 9223372036854775808.
-gmp(abs-1) :-
-    A is -9223372036854775808,
-    abs(A) =:= 9223372036854775808.
-gmp(sign-1) :-
-    -1 =:= sign(-5 rdiv 3),
-    0 =:= sign(0 rdiv 1),
-    1 =:= sign(2 rdiv 7),
-    fac(60, X),
-    -1 =:= sign(-X),
-    1 =:= sign(X).
-gmp(floor-1) :-
-    A is floor(1.0e20),
-    integer(A),
-    1.0e20 =:= float(A).
-gmp(floor-2) :-
-    0 is floor(9 rdiv 10),
-    -1 is floor(-1 rdiv 10),
-    -1 is floor(-9 rdiv 10).
-gmp(ceil-1) :-
-    A is ceil(1.0e20),
-    integer(A),
-    1.0e20 =:= float(A).
-gmp(ceil-2) :-
-    1 is ceil(9 rdiv 10),
-    0 is ceil(-1 rdiv 10),
-    0 is ceil(-9 rdiv 10).
-gmp(msb-0) :-
-    catch(0 =:= msb(0), E, true),
-    E = error(domain_error(not_less_than_one, 0), _).
-gmp(msb-1) :-
-    10 =:= msb(1<<10).
-gmp(msb-2) :-
-    100 =:= msb(1<<100).
-gmp(lsb-0) :-
-    catch(0 =:= lsb(0), E, true),
-    E = error(domain_error(not_less_than_one, 0), _).
-gmp(lsb-1) :-
-    10 =:= lsb(1<<10).
-gmp(lsb-2) :-
-    100 =:= lsb(1<<100).
-gmp(popcount-1) :-
-    1 =:= popcount(1<<5).
-gmp(popcount-2) :-
-    1 =:= popcount(1<<100).
-gmp(shift-1) :-
-    A is 1<<54, B is A<<8,
-    B =:= 4611686018427387904.
-gmp(shift-2) :-
-    A is 1<<55, B is A<<8,
-    B =:= 9223372036854775808.
-gmp(shift-3) :-
-    unbound(A),
-    forall(between(1, 100, X), % either resource error or representation error.
-           catch(A is 1<<(1<<X), error(_, _), true)).
-gmp(fac-1) :-
-    fac(25, X),
-    X == 15511210043330985984000000. % computed with bc
-gmp(arith-1) :-
-    A = 12345678901234567890123456789,
-    B = 7070707070707070707,
-    X is A * (A * B * A * B * A * B),
-    integer(X),
-    Y is B * A * B * A * B * A,
-    integer(Y),
-    R is X / Y,
-    R == A.
-gmp(pow-1) :-
-    A is 10**50, integer(A).
-gmp(pow-2) :-
-    A is -10**3, integer(A), A = -1000.
-gmp(pow-3) :-
-    A is 0**0, A = 1.
-gmp(pow-4) :-
-    A is -1**0, A = 1.
-gmp(pow-5) :-
-    A is -1**0, A = 1.
-gmp(pow-6) :-
-    A is -1**((1<<100)+1), A == -1.
-gmp(pow-7) :-
-    A is -100**5,
-    A < 0,
-    abs(A) =:= 100**5.
-gmp(powm-1) :-
-    A is powm(2,4,2),
-    A == 0.
-gmp(powm-2) :-
-    A is powm(2,4,3),
-    A == 1.
-gmp(integer-1) :-                       % rounding integer conversion
-    0 =:= integer(1 rdiv 3),
-    1 =:= integer(2 rdiv 3),
-    0 =:= integer(-1 rdiv 3),
-       -1 =:= integer(-2 rdiv 3).
-gmp(integer-2) :-
-    0 =:= integer(1/3),
-    1 =:= integer(2/3),
-    0 =:= integer(-1/3),
-       -1 =:= integer(-2/3).
-gmp(rational-1) :-                              % IEEE can represent 0.25
-    rational(1/4) =:= 1 rdiv 4.
-gmp(rational-2) :-
-    A is 2 rdiv 4,
-    rational(A, 1, 2).
-gmp(rational-3) :-
-    dec(6 rdiv 5, X),
-    rational(X, 1, 5).
-gmp(rational-4) :-
-    X is 5 rdiv 3,
-    rational(X, 5, 3).
-gmp(rationalize-1) :-
-    A is rationalize(0.0), A == 0,
-    B is rationalize(0.1), rational(B, 1, 10),
-    C is rationalize(10.0), C == 10,
-    D is rationalize(-0.1), rational(D, -1, 10).
-gmp(rationalize-2) :-
-    pi =:= float(rationalize(pi)).
-gmp(number-1) :-
-    A is 1 rdiv 3,
-    rational(A).
-gmp(float-1) :-
-    1/3 =:= float(1 rdiv 3).
-gmp(cmp-1) :-
-    0 < 3,
-    -1 < 0,
-    -1 < 1 rdiv 3,
-    1 > 0.3,
-    fac(100, F100), fac(200, F200), F100 < F200,
-    pi > 5 rdiv 2.
-gmp(clause-1) :-
-    Clause = (gmp_clause(X,Y) :-
-                   X is Y + 3353461138769748319272960000),
-    assert(Clause, Ref),
-    clause(H,B,Ref),
-    erase(Ref),
-    (H:-B) =@= Clause.
-gmp(comp-1) :-
-    retractall(gmp_clause(_,_)),
-    forall(between(1, 50, X),
-           (   oefac(X, Fac),
-               assert(gmp_clause(Fac, X))
-           )),
-    forall(between(1, 50, X),
-           (   oefac(X, Fac),
-               gmp_clause(Fac, Y),
-               X == Y,
-               clause(gmp_clause(Fac, Z), true),
-               X == Z
-           )),
-    retractall(gmp_clause(_,_)).
-gmp(comp-2) :-
-    X is ((1 rdiv 2)*2) rdiv 3,
-    rational(X, 1, 3).
-gmp(rec-1) :-
-    forall(recorded(gmp_fac, _, R), erase(R)),
-    forall(between(1, 50, X),
-           (   oefac(X, Fac),
-               recordz(gmp_fac, X-Fac)
-           )),
-    forall(between(1, 50, X),
-           (   oefac(X, Fac),
-               recorded(gmp_fac, X-Y),
-               Fac == Y
-           )),
-    forall(recorded(gmp_fac, _, R), erase(R)).
-gmp(number_codes-1) :-
-    fac(25, X),
-    number_codes(X, Codes),         % write
-    number_codes(Y, Codes),         % read
-    X == Y.
-gmp(atom_number-1) :-
-    fac(100, X),
-    atom_number(Atom, X),           % write
-    atom_number(Atom, Y),           % read
-    X == Y.
-gmp(hex-1) :-
-    atom_number('0xFFFFFFFFFFFFFFFF', 18446744073709551615).
-gmp(fmtd-1) :-
-    format(atom(X), '~d', [12345678901234567890123456]),
-    X == '12345678901234567890123456'.
-gmp(fmtd-2) :-
-    format(atom(X), '~2d', [12345678901234567890123456]),
-    X == '123456789012345678901234.56'.
-gmp(fmtD-1) :-
-    format(atom(X), '~D', [12345678901234567890123456]),
-    X == '12,345,678,901,234,567,890,123,456'.
-gmp(fmtD-2) :-
-    format(atom(X), '~2D', [12345678901234567890123456]),
-    X ==  '123,456,789,012,345,678,901,234.56'.
-gmp(fmtf-1) :-
-    ratp(999, 1, X),
-    format(atom(S), '~5f', [X]),
-    sub_atom(S, _, _, 0, '935376.65824').
-gmp(random) :-
-    A is random((1<<200)-((1<<200)-20)),
-    A < 20.
-gmp(length) :-
-    N is 1<<66,
-    catch(length(_L, N), Error, true),
-    Error = error(resource_error(stack), _).
-gmp(ar_add_ui) :-                       % check realloc of gmp number
-    A = 1000000000000000000000,
-    X is A+1,
-    X == 1000000000000000000001.
-
-:- endif.
-
 
                  /*******************************
                  *           CHARACTERS         *
@@ -2411,12 +1724,15 @@ load_program(include-1) :-
                  *******************************/
 
 :- dynamic
-    th_data/1,
-    at_exit_called/0.
+    th_data/1.
+
+:- if(current_predicate(thread_exit/1)).
+:- dynamic at_exit_called/0.
 
 at_exit_work :-
     thread_at_exit(assert(at_exit_called)),
     thread_exit(true).
+:- endif.
 
 th_do_something :-
     forall(between(1, 5, X),
@@ -2441,11 +1757,13 @@ thread(signal-1) :-
     thread_signal(Id, throw(stopit)),
     thread_join(Id, Exit),
     Exit == exception(stopit).
+:- if(current_predicate(at_exit_work/0)).
 thread(at_exit-1) :-
     retractall(at_exit_called),
     thread_create(at_exit_work, Id, []),
     thread_join(Id, exited(true)),
     retract(at_exit_called).
+:- endif.
 thread(status-1) :-
     thread_create(true, Id, []),
     between(0, 100, _),
@@ -2582,17 +1900,7 @@ script_failed(File, Except) :-
                  *        TEST MAIN-LOOP        *
                  *******************************/
 
-testset(syntax).
-testset(write_test).
-testset(format_test).
-testset(unify).
-testset(occurs_check).
-testset(unifiable).
-testset(arithmetic).
 testset(arithmetic_functions).
-testset(floattest).
-testset(gmp) :-
-    current_prolog_flag(bounded, false).
 testset(chars).
 testset(wchars).
 testset(depth_limit) :-
@@ -2625,8 +1933,6 @@ testset(exception).
 testset(term_atom).
 testset(os).
 testset(io).
-testset(popen) :-
-    current_prolog_flag(pipe, true).
 testset(timeout).
 testset(file).
 testset(unicode_file) :-
@@ -2710,9 +2016,24 @@ testdir('Tests/rational') :-
 
 test :-
     current_prolog_flag(argv, Argv),
-    argv_options(Argv, Files, Options),
+    argv_options(test:Argv, Files, Options),
     test(Files, Options).
 
+test:opt_type(list,     list_test_dirs, boolean).
+test:opt_type(l,        list_test_dirs, boolean).
+test:opt_type(core,     core,           boolean).
+test:opt_type(subdirs,  subdirs,        (boolean|term)).
+test:opt_type(packages, packages,       boolean).
+test:opt_type(package,  package,        atom).
+test:opt_type(output,   output,         oneof([always,never,on_failure])).
+
+test:opt_help(list_test_dirs, "List available directories with tests").
+test:opt_help(core,           "Run core tests").
+test:opt_help(subdirs,        "Prolog list of subdirectories to test").
+test:opt_help(packages,       "Test all packages").
+test:opt_help(package,        "Test named package").
+test:opt_help(output,         "When to write test output").
+
 %!  test(+Files, +Options)
 %
 %   Main test driver. If  Files  are   given,  these  test files are
@@ -2741,6 +2062,8 @@ test(_, Options) :-
 test(Files, Options) :-
     retractall(failed(_)),
     retractall(blocked(_,_)),
+    option(output(Output), Options, on_failure),
+    set_test_options([output(Output)]),
     (   option(core(false), Options)
     ->  true
     ;   forall(testset(Set), runtest(Set))
@@ -2787,8 +2110,11 @@ scripts(Dirs, _Options) :-
 test_packages(Options) :-
     option(packages(true), Options),
     !,
-    forall(find_package_test(Pkg, TestName, PkgScript, Goal, PkgDir),
-           run_pkg_test(Pkg, TestName, PkgScript, Goal, PkgDir)).
+    concurrent_forall(
+        find_package_test(Pkg, TestName, PkgScript, Goal, PkgDir),
+        run_pkg_test(Pkg, TestName, PkgScript, Goal, PkgDir),
+        [ threads(8)
+        ]).
 test_packages(Options) :-
     option(package(Pkg), Options),
     !,
@@ -2799,16 +2125,28 @@ test_packages(Options) :-
     ).
 test_packages(_).
 
+:- if(\+current_predicate(concurrent_forall/3)).
+concurrent_forall(Generate, Test, _Options) :-
+    forall(Generate, Test).
+:- endif.
+
+
 load_cmake_test_db :-
-    load_files(swi('test/cmake_pkg_tests.db')).
+    ensure_loaded(swi('test/cmake_pkg_tests.db')).
 
 find_package_test(Pkg, TestName, PkgScript, Goal, PkgDir) :-
     load_cmake_test_db,
-    cmake_test(Pkg, TestName, test_goal(PkgDir, PkgScript, Goal)).
+    cmake_test(Pkg, TestName, test_goal(PkgDir, PkgScript, Goal)),
+    is_pkg(Pkg).
 
 is_pkg(Pkg) :-
     load_cmake_test_db,
-    cmake_test(Pkg, _, test_goal(_, _, _)).
+    once(cmake_test(Pkg, _, test_goal(_, _, _))),
+    absolute_file_name(library(ext/Pkg), _,
+                       [ file_type(directory),
+                         access(exist),
+                         file_errors(fail)
+                       ]).
 
 %!  run_pkg_test(+Package, +TestName, +TestScript, +Goal, +PkgDir)
 %
@@ -2818,12 +2156,12 @@ is_pkg(Pkg) :-
 run_pkg_test(Pkg, TestName, PkgScript, Goal, PkgDir) :-
     script_dir(ScriptDir),
     atomic_list_concat([ScriptDir, PkgDir], /, TestDir),
-    format(user_error, '~NTesting package ~w:~w ~`.t~40|',[Pkg,TestName]),
+    format(user_error, '~N    Start testing package ~w:~w~n',[Pkg,TestName]),
     get_time(Start),
     run_pkg_test1(PkgScript, Goal, TestDir),
     get_time(End),
     Time is End - Start,
-    format(user_error, ' Passed ~2f sec.~n', [Time]).
+    format(user_error, 'Package ~w:~w~`.t~40| passed ~2f sec.~n', [Pkg,TestName,Time]).
 
 run_pkg_test1(Script, Goal, PkgDir) :-
     current_prolog_flag(executable, SWIPL),
